@@ -1905,6 +1905,7 @@ print_set_output(char *name, TBOOLEAN datablock, TBOOLEAN append_p)
 #endif
 	    if (0 > fclose(print_out))
 		perror(print_out_name);
+	print_out = stderr;
     }
 
     free(print_out_name);
@@ -2483,20 +2484,23 @@ toggle_command()
 
     } else if ((plottitle = try_to_get_string()) != NULL) {
 	struct curve_points *plot;
-	int length = strlen(plottitle);
+	int last = strlen(plottitle) - 1;
 	if (refresh_ok == E_REFRESH_OK_2D)
 	    plot = first_plot;
 	else if (refresh_ok == E_REFRESH_OK_3D)
 	    plot = (struct curve_points *)first_3dplot;
 	else
 	    plot = NULL;
-	for (plotno = 0; plot != NULL; plot = plot->next, plotno++) {
-	    if (plot->title)
-		if (!strcmp(plot->title, plottitle)
-		||  (plottitle[length-1] == '*' && !strncmp(plot->title, plottitle, length-1))) {
-		    foundit = TRUE;
-		    break;
-		}
+	if (last >= 0) {
+	    for (plotno = 0; plot != NULL; plot = plot->next, plotno++) {
+		if (plot->title)
+		    if (!strcmp(plot->title, plottitle)
+		    ||  (plottitle[last] == '*'
+			&& !strncmp(plot->title, plottitle, last))) {
+			foundit = TRUE;
+			break;
+		    }
+	    }
 	}
 	free(plottitle);
 	if (!foundit) {
@@ -3483,6 +3487,7 @@ expand_1level_macros()
 			while (*m)
 			    gp_input_line[o++] = (*m++);
 		    } else {
+			gp_input_line[o] = '\0';
 			int_warn( NO_CARET, "%s is not a string variable",m);
 		    }
 		    *c-- = temp_char;
